==> xmonad-contrib-0.12-1-armv7h.pkg.tar.xz: usr/share/haskell/xmonad-contrib/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xmonad-contrib
version: 0.12
id: xmonad-contrib-0.12-af1859b2ae003b6a6b4028d34e8fbf3e
key: xmona_Gv5db6cHJwhGkKHhQnr5Nm
license: BSD3
maintainer: xmonad@haskell.org
homepage: http://xmonad.org/
synopsis: Third party extensions for xmonad
description:
    Third party tiling algorithms, configurations and scripts to xmonad,
    a tiling window manager for X.
    .
    For an introduction to building, configuring and using xmonad
    extensions, see "XMonad.Doc". In particular:
    .
    "XMonad.Doc.Configuring", a guide to configuring xmonad
    .
    "XMonad.Doc.Extending", using the contributed extensions library
    .
    "XMonad.Doc.Developing", introduction to xmonad internals and writing
    your own extensions.
    .
category: System
author: Spencer Janssen & others
exposed: True
exposed-modules:
    XMonad.Doc XMonad.Doc.Configuring XMonad.Doc.Extending
    XMonad.Doc.Developing XMonad.Actions.AfterDrag
    XMonad.Actions.BluetileCommands XMonad.Actions.Commands
    XMonad.Actions.ConstrainedResize XMonad.Actions.CopyWindow
    XMonad.Actions.CycleRecentWS XMonad.Actions.CycleSelectedLayouts
    XMonad.Actions.CycleWindows XMonad.Actions.CycleWS
    XMonad.Actions.DeManage XMonad.Actions.DwmPromote
    XMonad.Actions.DynamicWorkspaces
    XMonad.Actions.DynamicWorkspaceGroups
    XMonad.Actions.DynamicWorkspaceOrder XMonad.Actions.DynamicProjects
    XMonad.Actions.FindEmptyWorkspace XMonad.Actions.FlexibleManipulate
    XMonad.Actions.FlexibleResize XMonad.Actions.FloatKeys
    XMonad.Actions.FloatSnap XMonad.Actions.FocusNth
    XMonad.Actions.GridSelect XMonad.Actions.GroupNavigation
    XMonad.Actions.Launcher XMonad.Actions.LinkWorkspaces
    XMonad.Actions.MessageFeedback XMonad.Actions.MouseGestures
    XMonad.Actions.MouseResize XMonad.Actions.Navigation2D
    XMonad.Actions.NoBorders XMonad.Actions.OnScreen
    XMonad.Actions.PerWorkspaceKeys XMonad.Actions.PhysicalScreens
    XMonad.Actions.Plane XMonad.Actions.Promote
    XMonad.Actions.RandomBackground XMonad.Actions.KeyRemap
    XMonad.Actions.RotSlaves XMonad.Actions.Search
    XMonad.Actions.ShowText XMonad.Actions.SimpleDate
    XMonad.Actions.SinkAll XMonad.Actions.SpawnOn XMonad.Actions.Submap
    XMonad.Actions.SwapWorkspaces XMonad.Actions.TagWindows
    XMonad.Actions.TopicSpace XMonad.Actions.UpdateFocus
    XMonad.Actions.UpdatePointer XMonad.Actions.Warp
    XMonad.Actions.WindowBringer XMonad.Actions.WindowGo
    XMonad.Actions.WindowMenu XMonad.Actions.WindowNavigation
    XMonad.Actions.WithAll XMonad.Actions.WorkspaceCursors
    XMonad.Actions.WorkspaceNames XMonad.Actions.Workscreen
    XMonad.Config.Arossato XMonad.Config.Azerty XMonad.Config.Bluetile
    XMonad.Config.Bepo XMonad.Config.Desktop XMonad.Config.Dmwit
    XMonad.Config.Droundy XMonad.Config.Gnome XMonad.Config.Kde
    XMonad.Config.Mate XMonad.Config.Prime XMonad.Config.Sjanssen
    XMonad.Config.Xfce XMonad.Hooks.CurrentWorkspaceOnTop
    XMonad.Hooks.DebugEvents XMonad.Hooks.DebugKeyEvents
    XMonad.Hooks.DynamicBars XMonad.Hooks.DynamicHooks
    XMonad.Hooks.DynamicLog XMonad.Hooks.DynamicProperty
    XMonad.Hooks.DebugStack XMonad.Hooks.EwmhDesktops
    XMonad.Hooks.FadeInactive XMonad.Hooks.FadeWindows
    XMonad.Hooks.FloatNext XMonad.Hooks.ICCCMFocus
    XMonad.Hooks.InsertPosition XMonad.Hooks.ManageDebug
    XMonad.Hooks.ManageDocks XMonad.Hooks.ManageHelpers
    XMonad.Hooks.Minimize XMonad.Hooks.Place
    XMonad.Hooks.PositionStoreHooks XMonad.Hooks.RestoreMinimized
    XMonad.Hooks.ScreenCorners XMonad.Hooks.Script
    XMonad.Hooks.ServerMode XMonad.Hooks.SetWMName
    XMonad.Hooks.ToggleHook XMonad.Hooks.UrgencyHook
    XMonad.Hooks.WallpaperSetter XMonad.Hooks.WorkspaceByPos
    XMonad.Hooks.WorkspaceHistory XMonad.Hooks.XPropManage
    XMonad.Layout.Accordion XMonad.Layout.AutoMaster
    XMonad.Layout.AvoidFloats XMonad.Layout.BinarySpacePartition
    XMonad.Layout.BorderResize XMonad.Layout.BoringWindows
    XMonad.Layout.ButtonDecoration XMonad.Layout.CenteredMaster
    XMonad.Layout.Circle XMonad.Layout.Column XMonad.Layout.Combo
    XMonad.Layout.ComboP XMonad.Layout.Cross XMonad.Layout.Decoration
    XMonad.Layout.DecorationAddons XMonad.Layout.DecorationMadness
    XMonad.Layout.Dishes XMonad.Layout.DraggingVisualizer
    XMonad.Layout.DragPane XMonad.Layout.Drawer XMonad.Layout.Dwindle
    XMonad.Layout.DwmStyle XMonad.Layout.FixedColumn
    XMonad.Layout.Fullscreen XMonad.Layout.Gaps XMonad.Layout.Grid
    XMonad.Layout.GridVariants XMonad.Layout.Groups
    XMonad.Layout.Groups.Examples XMonad.Layout.Groups.Helpers
    XMonad.Layout.Groups.Wmii XMonad.Layout.Hidden
    XMonad.Layout.HintedGrid XMonad.Layout.HintedTile
    XMonad.Layout.IfMax XMonad.Layout.IM
    XMonad.Layout.ImageButtonDecoration
    XMonad.Layout.IndependentScreens XMonad.Layout.LayoutBuilder
    XMonad.Layout.LayoutBuilderP XMonad.Layout.LayoutCombinators
    XMonad.Layout.LayoutHints XMonad.Layout.LayoutModifier
    XMonad.Layout.LayoutScreens XMonad.Layout.LimitWindows
    XMonad.Layout.MagicFocus XMonad.Layout.Magnifier
    XMonad.Layout.Master XMonad.Layout.Maximize
    XMonad.Layout.MessageControl XMonad.Layout.Minimize
    XMonad.Layout.Monitor XMonad.Layout.Mosaic XMonad.Layout.MosaicAlt
    XMonad.Layout.MouseResizableTile XMonad.Layout.MultiColumns
    XMonad.Layout.MultiToggle XMonad.Layout.MultiToggle.Instances
    XMonad.Layout.Named XMonad.Layout.NoBorders
    XMonad.Layout.NoFrillsDecoration XMonad.Layout.OnHost
    XMonad.Layout.OneBig XMonad.Layout.PerScreen
    XMonad.Layout.PerWorkspace XMonad.Layout.PositionStoreFloat
    XMonad.Layout.Reflect XMonad.Layout.Renamed
    XMonad.Layout.ResizableTile XMonad.Layout.ResizeScreen
    XMonad.Layout.Roledex XMonad.Layout.ShowWName
    XMonad.Layout.SimpleDecoration XMonad.Layout.SimpleFloat
    XMonad.Layout.Simplest XMonad.Layout.SimplestFloat
    XMonad.Layout.Spacing XMonad.Layout.Spiral XMonad.Layout.Square
    XMonad.Layout.StackTile XMonad.Layout.Stoppable
    XMonad.Layout.SubLayouts XMonad.Layout.TabBarDecoration
    XMonad.Layout.Tabbed XMonad.Layout.ThreeColumns
    XMonad.Layout.ToggleLayouts XMonad.Layout.TrackFloating
    XMonad.Layout.TwoPane XMonad.Layout.WindowArranger
    XMonad.Layout.WindowNavigation
    XMonad.Layout.WindowSwitcherDecoration XMonad.Layout.WorkspaceDir
    XMonad.Layout.ZoomRow XMonad.Prompt XMonad.Prompt.AppendFile
    XMonad.Prompt.AppLauncher XMonad.Prompt.ConfirmPrompt
    XMonad.Prompt.Directory XMonad.Prompt.DirExec XMonad.Prompt.Email
    XMonad.Prompt.Input XMonad.Prompt.Layout XMonad.Prompt.Man
    XMonad.Prompt.Pass XMonad.Prompt.RunOrRaise XMonad.Prompt.Shell
    XMonad.Prompt.Ssh XMonad.Prompt.Theme XMonad.Prompt.Window
    XMonad.Prompt.Workspace XMonad.Prompt.XMonad XMonad.Util.Cursor
    XMonad.Util.CustomKeys XMonad.Util.DebugWindow XMonad.Util.Dmenu
    XMonad.Util.Dzen XMonad.Util.ExtensibleState XMonad.Util.EZConfig
    XMonad.Util.Font XMonad.Util.Image XMonad.Util.Invisible
    XMonad.Util.Loggers XMonad.Util.NamedActions
    XMonad.Util.NamedScratchpad XMonad.Util.NamedWindows
    XMonad.Util.Paste XMonad.Util.PositionStore
    XMonad.Util.RemoteWindows XMonad.Util.Replace XMonad.Util.Run
    XMonad.Util.Scratchpad XMonad.Util.SpawnOnce
    XMonad.Util.SpawnNamedPipe XMonad.Util.Stack XMonad.Util.StringProp
    XMonad.Util.Themes XMonad.Util.Timer XMonad.Util.Types
    XMonad.Util.WindowProperties XMonad.Util.WindowState
    XMonad.Util.WorkspaceCompare XMonad.Util.XSelection
    XMonad.Util.XUtils
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/xmonad-contrib-0.12
library-dirs: /usr/lib/ghc-7.10.3/site-local/xmonad-contrib-0.12
data-dir: /usr/share/arm-linux-ghc-7.10.3/xmonad-contrib-0.12
hs-libraries: HSxmonad-contrib-0.12-Gv5db6cHJwhGkKHhQnr5Nm
depends:
    X11-1.6.1.2-4670912ab0053621e433826e2cb4ea46
    X11-xft-0.3.1-456bfecab00e6159ee7d2e78a2b26638
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    extensible-exceptions-0.1.1.4-8159918b63d70675389129eaecbf720a
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
    xmonad-0.12-8d8504347fd92509f5497e07981c17b8
haddock-interfaces: /usr/share/doc/xmonad-contrib/html/xmonad-contrib.haddock
haddock-html: /usr/share/doc/xmonad-contrib/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-contrib-0.12-2-armv7h.pkg.tar.xz: usr/share/haskell/xmonad-contrib/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xmonad-contrib
version: 0.12
id: xmonad-contrib-0.12-156cd3c0ca854565bf9faa6877178fbe
key: xmona_BEiG0Yr954U7d2Egxx4wKp
license: BSD3
maintainer: xmonad@haskell.org
homepage: http://xmonad.org/
synopsis: Third party extensions for xmonad
description:
    Third party tiling algorithms, configurations and scripts to xmonad,
    a tiling window manager for X.
    .
    For an introduction to building, configuring and using xmonad
    extensions, see "XMonad.Doc". In particular:
    .
    "XMonad.Doc.Configuring", a guide to configuring xmonad
    .
    "XMonad.Doc.Extending", using the contributed extensions library
    .
    "XMonad.Doc.Developing", introduction to xmonad internals and writing
    your own extensions.
    .
category: System
author: Spencer Janssen & others
exposed: True
exposed-modules:
    XMonad.Doc XMonad.Doc.Configuring XMonad.Doc.Extending
    XMonad.Doc.Developing XMonad.Actions.AfterDrag
    XMonad.Actions.BluetileCommands XMonad.Actions.Commands
    XMonad.Actions.ConstrainedResize XMonad.Actions.CopyWindow
    XMonad.Actions.CycleRecentWS XMonad.Actions.CycleSelectedLayouts
    XMonad.Actions.CycleWindows XMonad.Actions.CycleWS
    XMonad.Actions.DeManage XMonad.Actions.DwmPromote
    XMonad.Actions.DynamicWorkspaces
    XMonad.Actions.DynamicWorkspaceGroups
    XMonad.Actions.DynamicWorkspaceOrder XMonad.Actions.DynamicProjects
    XMonad.Actions.FindEmptyWorkspace XMonad.Actions.FlexibleManipulate
    XMonad.Actions.FlexibleResize XMonad.Actions.FloatKeys
    XMonad.Actions.FloatSnap XMonad.Actions.FocusNth
    XMonad.Actions.GridSelect XMonad.Actions.GroupNavigation
    XMonad.Actions.Launcher XMonad.Actions.LinkWorkspaces
    XMonad.Actions.MessageFeedback XMonad.Actions.MouseGestures
    XMonad.Actions.MouseResize XMonad.Actions.Navigation2D
    XMonad.Actions.NoBorders XMonad.Actions.OnScreen
    XMonad.Actions.PerWorkspaceKeys XMonad.Actions.PhysicalScreens
    XMonad.Actions.Plane XMonad.Actions.Promote
    XMonad.Actions.RandomBackground XMonad.Actions.KeyRemap
    XMonad.Actions.RotSlaves XMonad.Actions.Search
    XMonad.Actions.ShowText XMonad.Actions.SimpleDate
    XMonad.Actions.SinkAll XMonad.Actions.SpawnOn XMonad.Actions.Submap
    XMonad.Actions.SwapWorkspaces XMonad.Actions.TagWindows
    XMonad.Actions.TopicSpace XMonad.Actions.UpdateFocus
    XMonad.Actions.UpdatePointer XMonad.Actions.Warp
    XMonad.Actions.WindowBringer XMonad.Actions.WindowGo
    XMonad.Actions.WindowMenu XMonad.Actions.WindowNavigation
    XMonad.Actions.WithAll XMonad.Actions.WorkspaceCursors
    XMonad.Actions.WorkspaceNames XMonad.Actions.Workscreen
    XMonad.Config.Arossato XMonad.Config.Azerty XMonad.Config.Bluetile
    XMonad.Config.Bepo XMonad.Config.Desktop XMonad.Config.Dmwit
    XMonad.Config.Droundy XMonad.Config.Gnome XMonad.Config.Kde
    XMonad.Config.Mate XMonad.Config.Prime XMonad.Config.Sjanssen
    XMonad.Config.Xfce XMonad.Hooks.CurrentWorkspaceOnTop
    XMonad.Hooks.DebugEvents XMonad.Hooks.DebugKeyEvents
    XMonad.Hooks.DynamicBars XMonad.Hooks.DynamicHooks
    XMonad.Hooks.DynamicLog XMonad.Hooks.DynamicProperty
    XMonad.Hooks.DebugStack XMonad.Hooks.EwmhDesktops
    XMonad.Hooks.FadeInactive XMonad.Hooks.FadeWindows
    XMonad.Hooks.FloatNext XMonad.Hooks.ICCCMFocus
    XMonad.Hooks.InsertPosition XMonad.Hooks.ManageDebug
    XMonad.Hooks.ManageDocks XMonad.Hooks.ManageHelpers
    XMonad.Hooks.Minimize XMonad.Hooks.Place
    XMonad.Hooks.PositionStoreHooks XMonad.Hooks.RestoreMinimized
    XMonad.Hooks.ScreenCorners XMonad.Hooks.Script
    XMonad.Hooks.ServerMode XMonad.Hooks.SetWMName
    XMonad.Hooks.ToggleHook XMonad.Hooks.UrgencyHook
    XMonad.Hooks.WallpaperSetter XMonad.Hooks.WorkspaceByPos
    XMonad.Hooks.WorkspaceHistory XMonad.Hooks.XPropManage
    XMonad.Layout.Accordion XMonad.Layout.AutoMaster
    XMonad.Layout.AvoidFloats XMonad.Layout.BinarySpacePartition
    XMonad.Layout.BorderResize XMonad.Layout.BoringWindows
    XMonad.Layout.ButtonDecoration XMonad.Layout.CenteredMaster
    XMonad.Layout.Circle XMonad.Layout.Column XMonad.Layout.Combo
    XMonad.Layout.ComboP XMonad.Layout.Cross XMonad.Layout.Decoration
    XMonad.Layout.DecorationAddons XMonad.Layout.DecorationMadness
    XMonad.Layout.Dishes XMonad.Layout.DraggingVisualizer
    XMonad.Layout.DragPane XMonad.Layout.Drawer XMonad.Layout.Dwindle
    XMonad.Layout.DwmStyle XMonad.Layout.FixedColumn
    XMonad.Layout.Fullscreen XMonad.Layout.Gaps XMonad.Layout.Grid
    XMonad.Layout.GridVariants XMonad.Layout.Groups
    XMonad.Layout.Groups.Examples XMonad.Layout.Groups.Helpers
    XMonad.Layout.Groups.Wmii XMonad.Layout.Hidden
    XMonad.Layout.HintedGrid XMonad.Layout.HintedTile
    XMonad.Layout.IfMax XMonad.Layout.IM
    XMonad.Layout.ImageButtonDecoration
    XMonad.Layout.IndependentScreens XMonad.Layout.LayoutBuilder
    XMonad.Layout.LayoutBuilderP XMonad.Layout.LayoutCombinators
    XMonad.Layout.LayoutHints XMonad.Layout.LayoutModifier
    XMonad.Layout.LayoutScreens XMonad.Layout.LimitWindows
    XMonad.Layout.MagicFocus XMonad.Layout.Magnifier
    XMonad.Layout.Master XMonad.Layout.Maximize
    XMonad.Layout.MessageControl XMonad.Layout.Minimize
    XMonad.Layout.Monitor XMonad.Layout.Mosaic XMonad.Layout.MosaicAlt
    XMonad.Layout.MouseResizableTile XMonad.Layout.MultiColumns
    XMonad.Layout.MultiToggle XMonad.Layout.MultiToggle.Instances
    XMonad.Layout.Named XMonad.Layout.NoBorders
    XMonad.Layout.NoFrillsDecoration XMonad.Layout.OnHost
    XMonad.Layout.OneBig XMonad.Layout.PerScreen
    XMonad.Layout.PerWorkspace XMonad.Layout.PositionStoreFloat
    XMonad.Layout.Reflect XMonad.Layout.Renamed
    XMonad.Layout.ResizableTile XMonad.Layout.ResizeScreen
    XMonad.Layout.Roledex XMonad.Layout.ShowWName
    XMonad.Layout.SimpleDecoration XMonad.Layout.SimpleFloat
    XMonad.Layout.Simplest XMonad.Layout.SimplestFloat
    XMonad.Layout.Spacing XMonad.Layout.Spiral XMonad.Layout.Square
    XMonad.Layout.StackTile XMonad.Layout.Stoppable
    XMonad.Layout.SubLayouts XMonad.Layout.TabBarDecoration
    XMonad.Layout.Tabbed XMonad.Layout.ThreeColumns
    XMonad.Layout.ToggleLayouts XMonad.Layout.TrackFloating
    XMonad.Layout.TwoPane XMonad.Layout.WindowArranger
    XMonad.Layout.WindowNavigation
    XMonad.Layout.WindowSwitcherDecoration XMonad.Layout.WorkspaceDir
    XMonad.Layout.ZoomRow XMonad.Prompt XMonad.Prompt.AppendFile
    XMonad.Prompt.AppLauncher XMonad.Prompt.ConfirmPrompt
    XMonad.Prompt.Directory XMonad.Prompt.DirExec XMonad.Prompt.Email
    XMonad.Prompt.Input XMonad.Prompt.Layout XMonad.Prompt.Man
    XMonad.Prompt.Pass XMonad.Prompt.RunOrRaise XMonad.Prompt.Shell
    XMonad.Prompt.Ssh XMonad.Prompt.Theme XMonad.Prompt.Window
    XMonad.Prompt.Workspace XMonad.Prompt.XMonad XMonad.Util.Cursor
    XMonad.Util.CustomKeys XMonad.Util.DebugWindow XMonad.Util.Dmenu
    XMonad.Util.Dzen XMonad.Util.ExtensibleState XMonad.Util.EZConfig
    XMonad.Util.Font XMonad.Util.Image XMonad.Util.Invisible
    XMonad.Util.Loggers XMonad.Util.NamedActions
    XMonad.Util.NamedScratchpad XMonad.Util.NamedWindows
    XMonad.Util.Paste XMonad.Util.PositionStore
    XMonad.Util.RemoteWindows XMonad.Util.Replace XMonad.Util.Run
    XMonad.Util.Scratchpad XMonad.Util.SpawnOnce
    XMonad.Util.SpawnNamedPipe XMonad.Util.Stack XMonad.Util.StringProp
    XMonad.Util.Themes XMonad.Util.Timer XMonad.Util.Types
    XMonad.Util.WindowProperties XMonad.Util.WindowState
    XMonad.Util.WorkspaceCompare XMonad.Util.XSelection
    XMonad.Util.XUtils
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/xmonad-contrib-0.12
library-dirs: /usr/lib/ghc-7.10.3/site-local/xmonad-contrib-0.12
data-dir: /usr/share/arm-linux-ghc-7.10.3/xmonad-contrib-0.12
hs-libraries: HSxmonad-contrib-0.12-BEiG0Yr954U7d2Egxx4wKp
depends:
    X11-1.6.1.2-e77778265c7135c63ab82aead415c843
    X11-xft-0.3.1-66243f513e17481887364faf36406e3d
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    extensible-exceptions-0.1.1.4-8159918b63d70675389129eaecbf720a
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
    xmonad-0.12-1b489d5bde9ffbcde54a74a6f033bf73
haddock-interfaces: /usr/share/doc/xmonad-contrib/html/xmonad-contrib.haddock
haddock-html: /usr/share/doc/xmonad-contrib/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
